@@ -2,7 +2,7 @@ import sys
 import logging
 
 
-class Logger():
+class Logs_Manager():
     def __init__(self, log_name, log_level):
         self.log_name = log_name
         self.log_level = log_level
@@ -13,11 +13,14 @@ class Logger():
         if self.log_level == 'info':
             logger.setLevel(logging.INFO)  
 
-        if self.log_level == 'warning':
+        elif self.log_level == 'warning':
             logger.setLevel(logging.WARNING)  
 
-        if self.log_level == 'debug':
+        elif self.log_level == 'debug':
             logger.setLevel(logging.DEBUG)  
+
+        else:
+            logger.setLevel(logging.INFO)  
             
         formatter = logging.Formatter(  
             '%(levelname)s:%(module)s:%(message)s')
@@ -26,7 +29,6 @@ class Logger():
         
         handler.setFormatter(formatter)
         logger.addHandler(handler) 
-        _logger = logging.LoggerAdapter(logging.getLogger(self.log_name)) 
-        return _logger
+        return logger
 
 
